@@ -62,6 +62,7 @@ __all__ = (
     "ClientVpnRouteStatusCodeType",
     "ConnectionNotificationStateType",
     "ConnectionNotificationTypeType",
+    "ConnectivityTypeType",
     "ContainerFormatType",
     "ConversionTaskCancelledWaiterName",
     "ConversionTaskCompletedWaiterName",
@@ -470,6 +471,7 @@ ClientVpnEndpointStatusCodeType = Literal["available", "deleted", "deleting", "p
 ClientVpnRouteStatusCodeType = Literal["active", "creating", "deleting", "failed"]
 ConnectionNotificationStateType = Literal["Disabled", "Enabled"]
 ConnectionNotificationTypeType = Literal["Topic"]
+ConnectivityTypeType = Literal["private", "public"]
 ContainerFormatType = Literal["ova"]
 ConversionTaskCancelledWaiterName = Literal["conversion_task_cancelled"]
 ConversionTaskCompletedWaiterName = Literal["conversion_task_completed"]
